pub struct DhtRuntimeStats { /* private fields */ }Expand description
Cheap, cloneable handle for reading live DHT runtime statistics.
Implementations
Sourceimpl DhtRuntimeStats
impl DhtRuntimeStats
Sourcepub fn snapshot(&self) -> DhtRuntimeSnapshot
pub fn snapshot(&self) -> DhtRuntimeSnapshot
Load every exposed value once using relaxed atomics. Loads the core runtime counters and gauges using relaxed atomics.
Sourcepub fn observability_snapshot(&self) -> DhtObservabilitySnapshot
pub fn observability_snapshot(&self) -> DhtObservabilitySnapshot
Loads detailed transport counters, failure categories and fixed histograms.