pub enum MetadataFetchCompletionStatus {
Accepted,
FetchFailed,
DeliveryRejected,
}Expand description
Final outcome of a metadata fetch that passed the admission callback.
Variants
Accepted
Metadata was fetched and accepted by the torrent callback.
FetchFailed
All available peer candidates failed.
DeliveryRejected
Metadata was fetched, but the application did not accept it.